==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/ContainerConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs.builder
import com.pulumi.azurenative.batch.kotlin.enums.ContainerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property containerImageNames This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
 * @property containerRegistries If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
 * @property type
 */
public data class ContainerConfigurationArgs(
    public val containerImageNames: Output<List<String>>? = null,
    public val containerRegistries: Output<List<ContainerRegistryArgs>>? = null,
    public val type: Output<Either<String, ContainerType>>,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs =
        com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs.builder()
            .containerImageNames(containerImageNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .containerRegistries(
                containerRegistries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ContainerConfigurationArgs].
 */
@PulumiTagMarker
public class ContainerConfigurationArgsBuilder internal constructor() {
    private var containerImageNames: Output<List<String>>? = null

    private var containerRegistries: Output<List<ContainerRegistryArgs>>? = null

    private var type: Output<Either<String, ContainerType>>? = null

    /**
     * @param value This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("shcmhnfoywijxtsb")
    public suspend fun containerImageNames(`value`: Output<List<String>>) {
        this.containerImageNames = value
    }

    @JvmName("yfsywyxglwfuylfj")
    public suspend fun containerImageNames(vararg values: Output<String>) {
        this.containerImageNames = Output.all(values.asList())
    }

    /**
     * @param values This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("depsumovhtrutnld")
    public suspend fun containerImageNames(values: List<Output<String>>) {
        this.containerImageNames = Output.all(values)
    }

    /**
     * @param value If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("eomfughtyasardqn")
    public suspend fun containerRegistries(`value`: Output<List<ContainerRegistryArgs>>) {
        this.containerRegistries = value
    }

    @JvmName("nmrrehyfgovfxehx")
    public suspend fun containerRegistries(vararg values: Output<ContainerRegistryArgs>) {
        this.containerRegistries = Output.all(values.asList())
    }

    /**
     * @param values If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("pyohndhpsgroijpe")
    public suspend fun containerRegistries(values: List<Output<ContainerRegistryArgs>>) {
        this.containerRegistries = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("carxsjjwdynioqyh")
    public suspend fun type(`value`: Output<Either<String, ContainerType>>) {
        this.type = value
    }

    /**
     * @param value This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("myvevgpuhhibachc")
    public suspend fun containerImageNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerImageNames = mapped
    }

    /**
     * @param values This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("xkthxpjaykjucfnt")
    public suspend fun containerImageNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerImageNames = mapped
    }

    /**
     * @param value If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("xnebnkotogtwooap")
    public suspend fun containerRegistries(`value`: List<ContainerRegistryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("ufmpjoikhpijbmuy")
    public suspend
    fun containerRegistries(argument: List<suspend ContainerRegistryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ContainerRegistryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("klaeltlyypcjqtqs")
    public suspend fun containerRegistries(
        vararg
        argument: suspend ContainerRegistryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ContainerRegistryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("dpfgwibayhnoktci")
    public suspend
    fun containerRegistries(argument: suspend ContainerRegistryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ContainerRegistryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param values If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("cnoqijapvgjmsgvk")
    public suspend fun containerRegistries(vararg values: ContainerRegistryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerRegistries = mapped
    }

    /**
     * @param value
     */
    @JvmName("xawfgkfjqirgyelc")
    public suspend fun type(`value`: Either<String, ContainerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("ogypffpeycslimsx")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ContainerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("pxtknuvakjqugdum")
    public fun type(`value`: ContainerType) {
        val toBeMapped = Either.ofRight<String, ContainerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ContainerConfigurationArgs = ContainerConfigurationArgs(
        containerImageNames = containerImageNames,
        containerRegistries = containerRegistries,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/ContainerConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs.builder
import com.pulumi.azurenative.batch.kotlin.enums.ContainerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property containerImageNames This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
 * @property containerRegistries If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
 * @property type
 */
public data class ContainerConfigurationArgs(
    public val containerImageNames: Output<List<String>>? = null,
    public val containerRegistries: Output<List<ContainerRegistryArgs>>? = null,
    public val type: Output<Either<String, ContainerType>>,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs =
        com.pulumi.azurenative.batch.inputs.ContainerConfigurationArgs.builder()
            .containerImageNames(containerImageNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .containerRegistries(
                containerRegistries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ContainerConfigurationArgs].
 */
@PulumiTagMarker
public class ContainerConfigurationArgsBuilder internal constructor() {
    private var containerImageNames: Output<List<String>>? = null

    private var containerRegistries: Output<List<ContainerRegistryArgs>>? = null

    private var type: Output<Either<String, ContainerType>>? = null

    /**
     * @param value This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("hbwmucvsrnwjpnru")
    public suspend fun containerImageNames(`value`: Output<List<String>>) {
        this.containerImageNames = value
    }

    @JvmName("kkibfuretfctebgb")
    public suspend fun containerImageNames(vararg values: Output<String>) {
        this.containerImageNames = Output.all(values.asList())
    }

    /**
     * @param values This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("agaycweoluugfgqa")
    public suspend fun containerImageNames(values: List<Output<String>>) {
        this.containerImageNames = Output.all(values)
    }

    /**
     * @param value If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("yhrpevgqdybtbmuk")
    public suspend fun containerRegistries(`value`: Output<List<ContainerRegistryArgs>>) {
        this.containerRegistries = value
    }

    @JvmName("ohnwuawlrhradcjb")
    public suspend fun containerRegistries(vararg values: Output<ContainerRegistryArgs>) {
        this.containerRegistries = Output.all(values.asList())
    }

    /**
     * @param values If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("bedrajivvvqqwhqh")
    public suspend fun containerRegistries(values: List<Output<ContainerRegistryArgs>>) {
        this.containerRegistries = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yweddhxqtjngayqe")
    public suspend fun type(`value`: Output<Either<String, ContainerType>>) {
        this.type = value
    }

    /**
     * @param value This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("wamrxwwvmkfjwehx")
    public suspend fun containerImageNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerImageNames = mapped
    }

    /**
     * @param values This is the full image reference, as would be specified to "docker pull". An image will be sourced from the default Docker registry unless the image is fully qualified with an alternative registry.
     */
    @JvmName("gdyomnusvradxdgg")
    public suspend fun containerImageNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerImageNames = mapped
    }

    /**
     * @param value If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("nwixldebaxbrhvrx")
    public suspend fun containerRegistries(`value`: List<ContainerRegistryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("oalxasvomihjpewl")
    public suspend
    fun containerRegistries(argument: List<suspend ContainerRegistryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ContainerRegistryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("cgxbhcdnejsgwoma")
    public suspend fun containerRegistries(
        vararg
        argument: suspend ContainerRegistryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ContainerRegistryArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param argument If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("ymfhpevutxdxusug")
    public suspend
    fun containerRegistries(argument: suspend ContainerRegistryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ContainerRegistryArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.containerRegistries = mapped
    }

    /**
     * @param values If any images must be downloaded from a private registry which requires credentials, then those credentials must be provided here.
     */
    @JvmName("gucyfxsafatdimck")
    public suspend fun containerRegistries(vararg values: ContainerRegistryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerRegistries = mapped
    }

    /**
     * @param value
     */
    @JvmName("xscyftlitvfvsidw")
    public suspend fun type(`value`: Either<String, ContainerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("qdycasktdadkgtfl")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ContainerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("fpopdhxvyijvpabd")
    public fun type(`value`: ContainerType) {
        val toBeMapped = Either.ofRight<String, ContainerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ContainerConfigurationArgs = ContainerConfigurationArgs(
        containerImageNames = containerImageNames,
        containerRegistries = containerRegistries,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
